# SOM

Stanford Open Modules for Python

These are basic Python based tools for working with data (likely images and text) on Google Cloud. 

## Installation

      pip install git+git://github.com/vsoch/som.git


For (sometimes) more stable releases:


      pip install som
